@@ -5,10 +5,10 @@ pub(crate) mod externals;
 pub(crate) mod instance;
 pub(crate) mod mem_access;
 pub(crate) mod module;
-mod tunables;
+pub(super) mod tunables;
 pub(crate) mod typed_function;
 
-pub use crate::sys::engine::NativeEngineExt;
+pub use crate::sys::engine::{get_default_compiler_config, NativeEngineExt};
 pub use crate::sys::tunables::BaseTunables;
 #[cfg(feature = "compiler")]
 pub use wasmer_compiler::{
