@@ -57,9 +57,9 @@ impl Compile {
                 Target::new(target_triple.clone(), features)
             })
             .unwrap_or_default();
-        let (store, compiler_type) = self.store.get_store_for_target(target.clone())?;
+        let (mut store, compiler_type) = self.store.get_store_for_target(target.clone())?;
 
-        let mut engine = store.engine().clone();
+        let engine = store.engine_mut();
         let hash_algorithm = self.hash_algorithm.unwrap_or_default().into();
         engine.set_hash_algorithm(Some(hash_algorithm));
 
