@@ -1,17 +1,15 @@
 use anyhow::Context;
 
-use crate::{
-    commands::AsyncCliCommand,
-    opts::{ApiOpts, ItemFormatOpts},
-};
+use crate::{commands::AsyncCliCommand, config::WasmerEnv, opts::ItemFormatOpts};
 
 /// Show a namespace.
 #[derive(clap::Parser, Debug)]
 pub struct CmdNamespaceGet {
     #[clap(flatten)]
     fmt: ItemFormatOpts,
+
     #[clap(flatten)]
-    api: ApiOpts,
+    env: WasmerEnv,
 
     /// Name of the namespace.
     name: String,
@@ -22,7 +20,7 @@ impl AsyncCliCommand for CmdNamespaceGet {
     type Output = ();
 
     async fn run_async(self) -> Result<(), anyhow::Error> {
-        let client = self.api.client()?;
+        let client = self.env.client()?;
 
         let namespace = wasmer_api::query::get_namespace(&client, self.name)
             .await?
