@@ -1,7 +1,4 @@
-use crate::{
-    commands::AsyncCliCommand,
-    opts::{ApiOpts, ListFormatOpts},
-};
+use crate::{commands::AsyncCliCommand, config::WasmerEnv, opts::ListFormatOpts};
 
 /// List namespaces.
 #[derive(clap::Parser, Debug)]
@@ -9,7 +6,7 @@ pub struct CmdNamespaceList {
     #[clap(flatten)]
     fmt: ListFormatOpts,
     #[clap(flatten)]
-    api: ApiOpts,
+    env: WasmerEnv,
 }
 
 #[async_trait::async_trait]
@@ -17,7 +14,7 @@ impl AsyncCliCommand for CmdNamespaceList {
     type Output = ();
 
     async fn run_async(self) -> Result<(), anyhow::Error> {
-        let client = self.api.client()?;
+        let client = self.env.client()?;
 
         let namespaces = wasmer_api::query::user_namespaces(&client).await?;
 
