@@ -3,7 +3,7 @@ use crate::{
         package::common::{macros::*, wait::wait_package, *},
         AsyncCliCommand,
     },
-    opts::{ApiOpts, WasmerEnv},
+    config::WasmerEnv,
 };
 use anyhow::Context;
 use colored::Colorize;
@@ -23,9 +23,6 @@ use super::PublishWait;
 /// Tag an existing package.
 #[derive(Debug, clap::Parser)]
 pub struct PackageTag {
-    #[clap(flatten)]
-    pub api: ApiOpts,
-
     #[clap(flatten)]
     pub env: WasmerEnv,
 
@@ -151,6 +148,7 @@ impl PackageTag {
         Ok(Some(new_manifest))
     }
 
+    #[tracing::instrument]
     async fn do_tag(
         &self,
         client: &WasmerClient,
@@ -373,7 +371,7 @@ impl PackageTag {
     }
 
     async fn get_version(
-        &self,
+        &mut self,
         client: &WasmerClient,
         manifest: Option<&Manifest>,
         manifest_path: Option<&Path>,
@@ -425,6 +423,26 @@ impl PackageTag {
                 registry_version.clone()
             };
 
+            // Must necessarily bump if there's a package with the chosen version with a different hash.
+            let must_bump = {
+                let maybe_pkg = wasmer_api::query::get_package_version(
+                    client,
+                    full_pkg_name.to_string(),
+                    user_version.to_string(),
+                )
+                .await?;
+                let maybe_hash = maybe_pkg
+                    .as_ref()
+                    .and_then(|p| p.distribution_v3.pirita_sha256_hash.clone());
+
+                if let Some(hash) = maybe_hash {
+                    let registry_package_hash = PackageHash::from_str(&format!("sha256:{hash}"))?;
+                    registry_package_hash != self.package_hash
+                } else {
+                    false
+                }
+            };
+
             if user_version <= registry_version {
                 if self.bump {
                     user_version = registry_version.clone();
@@ -433,12 +451,34 @@ impl PackageTag {
                     let theme = ColorfulTheme::default();
                     let mut new_version = registry_version.clone();
                     new_version.patch += 1;
-                    if Confirm::with_theme(&theme)
-                        .with_prompt(format!("Do you want to bump the package's version ({user_version} -> {new_version})?"))
-                            .interact()? {
+                    if must_bump {
+                        eprintln!("{}: Registry already has version {user_version} of {full_pkg_name}, but with different contents.", "Warn".bold().yellow());
+                        eprintln!(
+                            "{}: Not bumping the version will make this action fail.",
+                            "Warn".bold().yellow()
+                        );
+                        let res = Confirm::with_theme(&theme)
+                            .with_prompt(format!("Continue ({user_version} -> {new_version})?"))
+                            .interact()?;
+                        if res {
                             user_version = new_version.clone();
-                            self.update_manifest_version(manifest_path, manifest, &user_version).await?;
-                       }
+                            self.update_manifest_version(manifest_path, manifest, &user_version)
+                                .await?;
+                        } else {
+                            anyhow::bail!(
+                                "Refusing to map two different releases of {full_pkg_name} to the same version."
+                            )
+                        }
+                    } else {
+                        let res = Confirm::with_theme(&theme)
+                        .with_prompt(format!("Do you want to bump the package's version ({user_version} -> {new_version})?"))
+                            .interact()?;
+                        if res {
+                            user_version = new_version.clone();
+                            self.update_manifest_version(manifest_path, manifest, &user_version)
+                                .await?;
+                        }
+                    }
                 }
             }
 
@@ -450,7 +490,9 @@ impl PackageTag {
                 Some(v) => Ok(v),
                 None => {
                     if self.non_interactive {
-                        anyhow::bail!("No package name specified: use --version <package_version>")
+                        anyhow::bail!(
+                            "No package version specified: use --version <package_version>"
+                        )
                     } else {
                         let version = crate::utils::prompts::prompt_for_package_version(
                             "Enter the package version",
@@ -468,7 +510,7 @@ impl PackageTag {
     }
 
     async fn synthesize_id(
-        &self,
+        &mut self,
         client: &WasmerClient,
         manifest: Option<&Manifest>,
         manifest_path: Option<&Path>,
@@ -504,7 +546,7 @@ impl PackageTag {
     }
 
     pub async fn tag(
-        &self,
+        &mut self,
         client: &WasmerClient,
         manifest: Option<&Manifest>,
         manifest_path: Option<&Path>,
@@ -539,6 +581,7 @@ impl PackageTag {
 
     // Check if a package with the same hash, namespace, name and version already exists. In such a
     // case, don't tag the package again.
+    #[tracing::instrument]
     async fn should_tag(&self, client: &WasmerClient, id: &NamedPackageId) -> anyhow::Result<bool> {
         if self.dry_run {
             if !self.quiet {
@@ -547,20 +590,24 @@ impl PackageTag {
             return Ok(false);
         }
 
-        if let Some(pkg) = wasmer_api::query::get_package_version(
+        let pkg = wasmer_api::query::get_package_version(
             client,
             id.full_name.clone(),
             id.version.to_string(),
         )
-        .await?
+        .await?;
+
+        if let Some(hash) = pkg
+            .as_ref()
+            .and_then(|p| p.distribution_v3.pirita_sha256_hash.as_ref())
         {
-            if let Some(hash) = pkg.distribution_v3.pirita_sha256_hash {
-                let registry_package_hash = PackageHash::from_str(&format!("sha256:{hash}"))?;
-                if registry_package_hash == self.package_hash {
-                    return Ok(false);
-                }
+            let registry_package_hash = PackageHash::from_str(&format!("sha256:{hash}"))?;
+            if registry_package_hash == self.package_hash {
+                tracing::info!("decided not to tag as package {pkg:?} already exists");
+                return Ok(false);
             }
         }
+
         Ok(true)
     }
 }
@@ -569,10 +616,9 @@ impl PackageTag {
 impl AsyncCliCommand for PackageTag {
     type Output = ();
 
-    async fn run_async(self) -> Result<Self::Output, anyhow::Error> {
+    async fn run_async(mut self) -> Result<Self::Output, anyhow::Error> {
         tracing::info!("Checking if user is logged in");
-        let client =
-            login_user(&self.api, &self.env, !self.non_interactive, "tag a package").await?;
+        let client = login_user(&self.env, !self.non_interactive, "tag a package").await?;
 
         let (manifest_path, manifest) = match get_manifest(&self.package_path) {
             Ok((manifest_path, manifest)) => {
