@@ -14,7 +14,8 @@ pub fn serialize<S: Serializer>(v: &[u8], s: S) -> Result<S::Ok, S::Error> {
 pub fn deserialize<'de, D: Deserializer<'de>>(d: D) -> Result<Cow<'static, [u8]>, D::Error> {
     let base64 = String::deserialize(d)?;
     #[allow(deprecated)]
-    base64::decode(decompress_size_prepended(base64.as_bytes()).map_err(serde::de::Error::custom)?)
+    let bytes = base64::decode(base64).map_err(serde::de::Error::custom)?;
+    decompress_size_prepended(&bytes)
         .map_err(serde::de::Error::custom)
         .map(|d| d.into())
 }
