@@ -1379,7 +1379,7 @@ mod test_read_write_seek {
 
         let mut buffer = [0; 16];
         assert!(
-            matches!(file.read_exact(&mut buffer).await, Err(_)),
+            file.read_exact(&mut buffer).await.is_err(),
             "failing to read an exact buffer",
         );
 
@@ -1390,7 +1390,7 @@ mod test_read_write_seek {
 
         let mut buffer = [0; 3];
         assert!(
-            matches!(file.read_exact(&mut buffer).await, Ok(_)),
+            file.read_exact(&mut buffer).await.is_ok(),
             "failing to read an exact buffer",
         );
     }
