@@ -2,92 +2,38 @@
 //! its not as simple as TmpFs. not currently used but was used by
 //! the previoulsy implementation of Deploy - now using TmpFs
 
+use dashmap::DashMap;
+
 use crate::*;
 
-use std::{
-    path::Path,
-    sync::{Arc, Mutex, Weak},
-};
-
-use tracing::{debug, trace};
-
-pub type TempHolding = Arc<Mutex<Option<Arc<Box<dyn FileSystem>>>>>;
+use std::{path::Path, sync::Arc};
 
 #[derive(Debug)]
 pub struct MountPoint {
-    pub path: String,
+    pub path: PathBuf,
     pub name: String,
-    pub fs: Option<Arc<Box<dyn FileSystem>>>,
-    pub weak_fs: Weak<Box<dyn FileSystem>>,
-    pub temp_holding: TempHolding,
-    pub should_sanitize: bool,
-    pub new_path: Option<String>,
-}
-
-impl Clone for MountPoint {
-    fn clone(&self) -> Self {
-        Self {
-            path: self.path.clone(),
-            name: self.name.clone(),
-            fs: None,
-            weak_fs: self.weak_fs.clone(),
-            temp_holding: self.temp_holding.clone(),
-            should_sanitize: self.should_sanitize,
-            new_path: self.new_path.clone(),
-        }
-    }
+    pub fs: Arc<Box<dyn FileSystem + Send + Sync>>,
 }
 
 impl MountPoint {
-    pub fn fs(&self) -> Option<Arc<Box<dyn FileSystem>>> {
-        match &self.fs {
-            Some(a) => Some(a.clone()),
-            None => self.weak_fs.upgrade(),
-        }
+    pub fn fs(&self) -> &(dyn FileSystem + Send + Sync) {
+        self.fs.as_ref()
     }
 
-    /// Tries to recover the internal `Weak<dyn FileSystem>` to a `Arc<dyn FileSystem>`
-    fn solidify(&mut self) {
-        if self.fs.is_none() {
-            self.fs = self.weak_fs.upgrade();
-        }
-        {
-            let mut guard = self.temp_holding.lock().unwrap();
-            let fs = guard.take();
-            if self.fs.is_none() {
-                self.fs = fs;
-            }
-        }
-    }
-
-    /// Returns a strong-referenced copy of the internal `Arc<dyn FileSystem>`
-    fn strong(&self) -> Option<StrongMountPoint> {
-        self.fs().map(|fs| StrongMountPoint {
+    pub fn mount_point_ref(&self) -> MountPointRef<'_> {
+        MountPointRef {
             path: self.path.clone(),
             name: self.name.clone(),
-            fs,
-            should_sanitize: self.should_sanitize,
-            new_path: self.new_path.clone(),
-        })
+            fs: &self.fs,
+        }
     }
 }
 
-/// A `strong` mount point holds a strong `Arc` reference to the filesystem
-/// mounted at path `path`.
-#[derive(Debug)]
-pub struct StrongMountPoint {
-    pub path: String,
-    pub name: String,
-    pub fs: Arc<Box<dyn FileSystem>>,
-    pub should_sanitize: bool,
-    pub new_path: Option<String>,
-}
-
 /// Allows different filesystems of different types
 /// to be mounted at various mount points
-#[derive(Debug, Default, Clone)]
+#[derive(Debug, Default)]
 pub struct UnionFileSystem {
-    pub mounts: Vec<MountPoint>,
+    pub mounts: DashMap<PathBuf, MountPoint>,
 }
 
 impl UnionFileSystem {
@@ -98,350 +44,239 @@ impl UnionFileSystem {
     pub fn clear(&mut self) {
         self.mounts.clear();
     }
+
+    fn is_root(&self) -> bool {
+        self.mounts.len() == 1 && self.mounts.contains_key(&PathBuf::from("/"))
+    }
+
+    fn prepare_path(&self, path: &Path) -> PathBuf {
+        if self.is_root() {
+            path.to_owned()
+        } else {
+            path.strip_prefix(PathBuf::from("/"))
+                .unwrap_or(path)
+                .to_owned()
+        }
+    }
 }
 
 impl UnionFileSystem {
-    pub fn mount(
-        &mut self,
-        name: &str,
-        path: &str,
-        should_sanitize: bool,
-        fs: Box<dyn FileSystem>,
-        new_path: Option<&str>,
-    ) {
-        self.unmount(path);
-        let mut path = path.to_string();
-        if !path.starts_with('/') {
-            path.insert(0, '/');
-        }
-        if !path.ends_with('/') {
-            path += "/";
-        }
-        let new_path = new_path.map(|new_path| {
-            let mut new_path = new_path.to_string();
-            if !new_path.ends_with('/') {
-                new_path += "/";
-            }
-            new_path
-        });
-        let fs = Arc::new(fs);
+    #[allow(clippy::type_complexity)]
+    fn find_mount(
+        &self,
+        path: PathBuf,
+    ) -> Option<(PathBuf, PathBuf, Arc<Box<dyn FileSystem + Send + Sync>>)> {
+        let mut components = path.components().collect::<Vec<_>>();
 
-        let mount = MountPoint {
-            path,
-            name: name.to_string(),
-            fs: None,
-            weak_fs: Arc::downgrade(&fs),
-            temp_holding: Arc::new(Mutex::new(Some(fs.clone()))),
-            should_sanitize,
-            new_path,
-        };
+        if let Some(c) = components.first().copied() {
+            components.remove(0);
 
-        self.mounts.push(mount);
-    }
+            let sub_path = components.into_iter().collect::<PathBuf>();
 
-    pub fn unmount(&mut self, path: &str) {
-        let path1 = path.to_string();
-        let mut path2 = path1;
-        if !path2.starts_with('/') {
-            path2.insert(0, '/');
-        }
-        let mut path3 = path2.clone();
-        if !path3.ends_with('/') {
-            path3.push('/')
-        }
-        if path2.ends_with('/') {
-            path2 = (path2[..(path2.len() - 1)]).to_string();
-        }
-
-        self.mounts
-            .retain(|mount| mount.path != path2 && mount.path != path3);
-    }
-
-    fn read_dir_internal(&self, path: &Path) -> Result<ReadDir> {
-        let path = path.to_string_lossy();
-
-        let mut ret = None;
-        for (path, mount) in filter_mounts(&self.mounts, path.as_ref()) {
-            match mount.fs.read_dir(Path::new(path.as_str())) {
-                Ok(dir) => {
-                    if ret.is_none() {
-                        ret = Some(Vec::new());
-                    }
-                    let ret = ret.as_mut().unwrap();
-                    for sub in dir.flatten() {
-                        ret.push(sub);
-                    }
-                }
-                Err(err) => {
-                    debug!("failed to read dir - {}", err);
-                }
+            if let Some(mount) = self.mounts.get(&PathBuf::from(c.as_os_str())) {
+                return Some((
+                    PathBuf::from(c.as_os_str()),
+                    PathBuf::from("/").join(sub_path),
+                    mount.fs.clone(),
+                ));
             }
         }
 
-        match ret {
-            Some(mut ret) => {
-                ret.sort_by(|a, b| match (a.metadata.as_ref(), b.metadata.as_ref()) {
-                    (Ok(a), Ok(b)) => a.modified.cmp(&b.modified),
-                    _ => std::cmp::Ordering::Equal,
-                });
-                Ok(ReadDir::new(ret))
-            }
-            None => Err(FsError::EntryNotFound),
-        }
-    }
-
-    /// Deletes all mount points that do not have `sanitize` set in the options
-    pub fn sanitize(mut self) -> Self {
-        self.solidify();
-        self.mounts.retain(|mount| !mount.should_sanitize);
-        self
-    }
-
-    /// Tries to recover the internal `Weak<dyn FileSystem>` to a `Arc<dyn FileSystem>`
-    pub fn solidify(&mut self) {
-        for mount in self.mounts.iter_mut() {
-            mount.solidify();
-        }
+        None
     }
 }
 
 impl FileSystem for UnionFileSystem {
     fn readlink(&self, path: &Path) -> Result<PathBuf> {
-        debug!("readlink: path={}", path.display());
-        let mut ret_error = FsError::EntryNotFound;
-        let path = path.to_string_lossy();
-        for (path_inner, mount) in filter_mounts(&self.mounts, path.as_ref()) {
-            match mount.fs.readlink(Path::new(path_inner.as_str())) {
-                Ok(ret) => {
-                    return Ok(ret);
-                }
-                Err(err) => {
-                    // This fixes a bug when attempting to create the directory /usr when it does not exist
-                    // on the x86 version of memfs
-                    // TODO: patch virtual-fs and remove
-                    if let FsError::NotAFile = &err {
-                        ret_error = FsError::EntryNotFound;
-                    } else {
-                        debug!("readlink failed: (path={}) - {}", path, err);
-                        ret_error = err;
-                    }
-                }
-            }
+        let path = self.prepare_path(path);
+
+        if path.as_os_str().is_empty() {
+            Err(FsError::NotAFile)
+        } else if let Some((_, path, fs)) = self.find_mount(path.to_owned()) {
+            fs.readlink(&path)
+        } else {
+            Err(FsError::EntryNotFound)
         }
-        debug!("readlink: failed={}", ret_error);
-        Err(ret_error)
     }
 
     fn read_dir(&self, path: &Path) -> Result<ReadDir> {
-        debug!("read_dir: path={}", path.display());
-        self.read_dir_internal(path)
-    }
-    fn create_dir(&self, path: &Path) -> Result<()> {
-        debug!("create_dir: path={}", path.display());
-        if path.parent().is_none() {
-            return Err(FsError::BaseNotDirectory);
-        }
-        if self.read_dir_internal(path).is_ok() {
-            //return Err(FsError::AlreadyExists);
-            return Ok(());
-        }
+        let path = self.prepare_path(path);
 
-        let path = path.to_string_lossy();
-        let mut ret_error = FsError::EntryNotFound;
-        for (path, mount) in filter_mounts(&self.mounts, path.as_ref()) {
-            match mount.fs.create_dir(Path::new(path.as_str())) {
-                Ok(ret) => {
-                    return Ok(ret);
-                }
-                Err(err) => {
-                    ret_error = err;
+        if path.as_os_str().is_empty() {
+            let entries = self
+                .mounts
+                .iter()
+                .map(|i| DirEntry {
+                    path: PathBuf::from("/").join(i.key()),
+                    metadata: Ok(Metadata {
+                        ft: FileType::new_dir(),
+                        accessed: 0,
+                        created: 0,
+                        modified: 0,
+                        len: 0,
+                    }),
+                })
+                .collect::<Vec<_>>();
+
+            Ok(ReadDir::new(entries))
+        } else if let Some((prefix, path, fs)) = self.find_mount(path.to_owned()) {
+            let mut entries = fs.read_dir(&path)?;
+
+            for entry in &mut entries.data {
+                let path: PathBuf = entry.path.components().skip(1).collect();
+                entry.path = PathBuf::from("/").join(PathBuf::from(&prefix).join(path));
+            }
+
+            Ok(entries)
+        } else {
+            Err(FsError::EntryNotFound)
+        }
+    }
+
+    fn create_dir(&self, path: &Path) -> Result<()> {
+        let path = self.prepare_path(path);
+
+        if path.as_os_str().is_empty() {
+            Ok(())
+        } else if let Some((_, path, fs)) = self.find_mount(path.to_owned()) {
+            let result = fs.create_dir(&path);
+
+            if let Err(e) = result {
+                if e == FsError::AlreadyExists {
+                    return Ok(());
                 }
             }
+
+            result
+        } else {
+            Err(FsError::EntryNotFound)
         }
-        Err(ret_error)
     }
     fn remove_dir(&self, path: &Path) -> Result<()> {
-        debug!("remove_dir: path={}", path.display());
-        if path.parent().is_none() {
-            return Err(FsError::BaseNotDirectory);
+        let path = self.prepare_path(path);
+
+        if path.as_os_str().is_empty() {
+            Err(FsError::PermissionDenied)
+        } else if let Some((_, path, fs)) = self.find_mount(path.to_owned()) {
+            fs.remove_dir(&path)
+        } else {
+            Err(FsError::EntryNotFound)
         }
-        // https://github.com/rust-lang/rust/issues/86442
-        // DirectoryNotEmpty is not implemented consistently
-        if path.is_dir() && self.read_dir(path).map(|s| !s.is_empty()).unwrap_or(false) {
-            return Err(FsError::DirectoryNotEmpty);
-        }
-        let mut ret_error = FsError::EntryNotFound;
-        let path = path.to_string_lossy();
-        for (path, mount) in filter_mounts(&self.mounts, path.as_ref()) {
-            match mount.fs.remove_dir(Path::new(path.as_str())) {
-                Ok(ret) => {
-                    return Ok(ret);
-                }
-                Err(err) => {
-                    ret_error = err;
-                }
-            }
-        }
-        Err(ret_error)
     }
     fn rename<'a>(&'a self, from: &'a Path, to: &'a Path) -> BoxFuture<'a, Result<()>> {
-        Box::pin(async {
-            println!("rename: from={} to={}", from.display(), to.display());
-            if from.parent().is_none() {
-                return Err(FsError::BaseNotDirectory);
+        Box::pin(async move {
+            let from = self.prepare_path(from);
+            let to = self.prepare_path(to);
+
+            if from.as_os_str().is_empty() {
+                Err(FsError::PermissionDenied)
+            } else if let Some((prefix, path, fs)) = self.find_mount(from.to_owned()) {
+                let to = to.strip_prefix(prefix).map_err(|_| FsError::InvalidInput)?;
+
+                let to = PathBuf::from("/").join(to);
+
+                fs.rename(&path, &to).await
+            } else {
+                Err(FsError::EntryNotFound)
             }
-            if to.parent().is_none() {
-                return Err(FsError::BaseNotDirectory);
-            }
-            let mut ret_error = FsError::EntryNotFound;
-            let from = from.to_string_lossy();
-            let to = to.to_string_lossy();
-            #[cfg(target_os = "windows")]
-            let to = to.replace('\\', "/");
-            for (path, mount) in filter_mounts(&self.mounts, from.as_ref()) {
-                let mut to = if to.starts_with(mount.path.as_str()) {
-                    (to[mount.path.len()..]).to_string()
-                } else {
-                    ret_error = FsError::UnknownError;
-                    continue;
-                };
-                if !to.starts_with('/') {
-                    to = format!("/{}", to);
-                }
-                match mount
-                    .fs
-                    .rename(Path::new(&path), Path::new(to.as_str()))
-                    .await
-                {
-                    Ok(ret) => {
-                        trace!("rename ok");
-                        return Ok(ret);
-                    }
-                    Err(err) => {
-                        trace!("rename error (from={}, to={}) - {}", from, to, err);
-                        ret_error = err;
-                    }
-                }
-            }
-            trace!("rename failed - {}", ret_error);
-            Err(ret_error)
         })
     }
     fn metadata(&self, path: &Path) -> Result<Metadata> {
-        debug!("metadata: path={}", path.display());
-        let mut ret_error = FsError::EntryNotFound;
-        let path = path.to_string_lossy();
-        for (path, mount) in filter_mounts(&self.mounts, path.as_ref()) {
-            match mount.fs.metadata(Path::new(path.as_str())) {
-                Ok(ret) => {
-                    return Ok(ret);
-                }
-                Err(err) => {
-                    // This fixes a bug when attempting to create the directory /usr when it does not exist
-                    // on the x86 version of memfs
-                    // TODO: patch virtual-fs and remove
-                    if let FsError::NotAFile = &err {
-                        ret_error = FsError::EntryNotFound;
-                    } else {
-                        debug!("metadata failed: (path={}) - {}", path, err);
-                        ret_error = err;
-                    }
-                }
-            }
+        let path = self.prepare_path(path);
+
+        if path.as_os_str().is_empty() {
+            Ok(Metadata {
+                ft: FileType::new_dir(),
+                accessed: 0,
+                created: 0,
+                modified: 0,
+                len: 0,
+            })
+        } else if let Some((_, path, fs)) = self.find_mount(path.to_owned()) {
+            fs.metadata(&path)
+        } else {
+            Err(FsError::EntryNotFound)
         }
-        Err(ret_error)
     }
     fn symlink_metadata(&self, path: &Path) -> Result<Metadata> {
-        debug!("symlink_metadata: path={}", path.display());
-        let mut ret_error = FsError::EntryNotFound;
-        let path = path.to_string_lossy();
-        for (path_inner, mount) in filter_mounts(&self.mounts, path.as_ref()) {
-            match mount.fs.symlink_metadata(Path::new(path_inner.as_str())) {
-                Ok(ret) => {
-                    return Ok(ret);
-                }
-                Err(err) => {
-                    // This fixes a bug when attempting to create the directory /usr when it does not exist
-                    // on the x86 version of memfs
-                    // TODO: patch virtual-fs and remove
-                    if let FsError::NotAFile = &err {
-                        ret_error = FsError::EntryNotFound;
-                    } else {
-                        debug!("metadata failed: (path={}) - {}", path, err);
-                        ret_error = err;
-                    }
-                }
-            }
+        let path = self.prepare_path(path);
+
+        if path.as_os_str().is_empty() {
+            Ok(Metadata {
+                ft: FileType::new_dir(),
+                accessed: 0,
+                created: 0,
+                modified: 0,
+                len: 0,
+            })
+        } else if let Some((_, path, fs)) = self.find_mount(path.to_owned()) {
+            fs.symlink_metadata(&path)
+        } else {
+            Err(FsError::EntryNotFound)
         }
-        debug!("symlink_metadata: failed={}", ret_error);
-        Err(ret_error)
     }
     fn remove_file(&self, path: &Path) -> Result<()> {
-        println!("remove_file: path={}", path.display());
-        let mut ret_error = FsError::EntryNotFound;
-        let path = path.to_string_lossy();
-        for (path, mount) in filter_mounts(&self.mounts, path.as_ref()) {
-            match mount.fs.remove_file(Path::new(path.as_str())) {
-                Ok(ret) => {
-                    return Ok(ret);
-                }
-                Err(err) => {
-                    println!("returning error {err:?}");
-                    ret_error = err;
-                }
-            }
+        let path = self.prepare_path(path);
+
+        if path.as_os_str().is_empty() {
+            Err(FsError::NotAFile)
+        } else if let Some((_, path, fs)) = self.find_mount(path.to_owned()) {
+            fs.remove_file(&path)
+        } else {
+            Err(FsError::EntryNotFound)
         }
-        Err(ret_error)
     }
     fn new_open_options(&self) -> OpenOptions {
         OpenOptions::new(self)
     }
+
+    fn mount(
+        &self,
+        name: String,
+        path: &Path,
+        fs: Box<dyn FileSystem + Send + Sync>,
+    ) -> Result<()> {
+        let mut components = path.components().collect::<Vec<_>>();
+        if let Some(c) = components.first().copied() {
+            components.remove(0);
+
+            let sub_path = components.into_iter().collect::<PathBuf>();
+
+            if let Some(mount) = self.mounts.get(&PathBuf::from(c.as_os_str())) {
+                return mount.fs.mount(name, sub_path.as_path(), fs);
+            }
+
+            let fs = if sub_path.components().next().is_none() {
+                fs
+            } else {
+                let union = UnionFileSystem::new();
+                union.mount(name.clone(), sub_path.as_path(), fs)?;
+
+                Box::new(union)
+            };
+
+            let fs = Arc::new(fs);
+
+            let mount = MountPoint {
+                path: PathBuf::from(c.as_os_str()),
+                name,
+                fs,
+            };
+
+            self.mounts.insert(PathBuf::from(c.as_os_str()), mount);
+        } else {
+            return Err(FsError::EntryNotFound);
+        }
+
+        Ok(())
+    }
 }
 
-fn filter_mounts(
-    mounts: &[MountPoint],
-    target: &str,
-) -> impl Iterator<Item = (String, StrongMountPoint)> {
-    // On Windows, Path might use \ instead of /, wich mill messup the matching of mount points
-    #[cfg(target_os = "windows")]
-    let target = target.replace('\\', "/");
-
-    let mut biggest_path = 0usize;
-    let mut ret = Vec::new();
-    for mount in mounts.iter().rev() {
-        let mut test_mount_path1 = mount.path.clone();
-        if !test_mount_path1.ends_with('/') {
-            test_mount_path1.push('/');
-        }
-
-        let mut test_mount_path2 = mount.path.clone();
-        if test_mount_path2.ends_with('/') {
-            test_mount_path2 = test_mount_path2[..(test_mount_path2.len() - 1)].to_string();
-        }
-
-        if target == test_mount_path1 || target == test_mount_path2 {
-            if let Some(mount) = mount.strong() {
-                biggest_path = biggest_path.max(mount.path.len());
-                let mut path = "/".to_string();
-                if let Some(ref np) = mount.new_path {
-                    path = np.to_string();
-                }
-                ret.push((path, mount));
-            }
-        } else if target.starts_with(test_mount_path1.as_str()) {
-            if let Some(mount) = mount.strong() {
-                biggest_path = biggest_path.max(mount.path.len());
-                let path = &target[test_mount_path2.len()..];
-                let mut path = path.to_string();
-                if let Some(ref np) = mount.new_path {
-                    path = format!("{}{}", np, &path[1..]);
-                }
-                ret.push((path, mount));
-            }
-        }
-    }
-    ret.retain(|(_, b)| b.path.len() >= biggest_path);
-    ret.into_iter()
+#[derive(Debug)]
+pub struct MountPointRef<'a> {
+    pub path: PathBuf,
+    pub name: String,
+    pub fs: &'a dyn FileSystem,
 }
 
 impl FileOpener for UnionFileSystem {
@@ -450,53 +285,39 @@ impl FileOpener for UnionFileSystem {
         path: &Path,
         conf: &OpenOptionsConfig,
     ) -> Result<Box<dyn VirtualFile + Send + Sync>> {
-        debug!("open: path={}", path.display());
-        let mut ret_err = FsError::EntryNotFound;
-        let path = path.to_string_lossy();
+        let path = self.prepare_path(path);
 
-        if conf.create() || conf.create_new() {
-            for (path, mount) in filter_mounts(&self.mounts, path.as_ref()) {
-                if let Ok(mut ret) = mount
-                    .fs
-                    .new_open_options()
-                    .truncate(conf.truncate())
-                    .append(conf.append())
-                    .read(conf.read())
-                    .write(conf.write())
-                    .open(path)
-                {
-                    if conf.create_new() {
-                        ret.unlink().ok();
-                        continue;
-                    }
-                    return Ok(ret);
-                }
+        if path.as_os_str().is_empty() {
+            Err(FsError::NotAFile)
+        } else {
+            let parent = path.parent().unwrap();
+            let file_name = path.file_name().unwrap();
+            if let Some((_, path, fs)) = self.find_mount(parent.to_owned()) {
+                fs.new_open_options()
+                    .options(conf.clone())
+                    .open(path.join(file_name))
+            } else {
+                Err(FsError::EntryNotFound)
             }
         }
-        for (path, mount) in filter_mounts(&self.mounts, path.as_ref()) {
-            match mount.fs.new_open_options().options(conf.clone()).open(path) {
-                Ok(ret) => return Ok(ret),
-                Err(err) if ret_err == FsError::EntryNotFound => {
-                    ret_err = err;
-                }
-                _ => {}
-            }
-        }
-        Err(ret_err)
     }
 }
 
 #[cfg(test)]
 mod tests {
-    use std::path::Path;
+    use std::{
+        collections::HashSet,
+        path::{Path, PathBuf},
+    };
 
     use tokio::io::AsyncWriteExt;
 
-    use crate::{mem_fs, ops, FileSystem as FileSystemTrait, FsError, UnionFileSystem};
+    use crate::{mem_fs, FileSystem as FileSystemTrait, FsError, UnionFileSystem};
+
+    use super::{FileOpener, OpenOptionsConfig};
 
     fn gen_filesystem() -> UnionFileSystem {
-        let mut union = UnionFileSystem::new();
-        // fs.mount("/", Box::new(mem_fs::FileSystem::default()));
+        let union = UnionFileSystem::new();
         let a = mem_fs::FileSystem::default();
         let b = mem_fs::FileSystem::default();
         let c = mem_fs::FileSystem::default();
@@ -506,18 +327,177 @@ mod tests {
         let g = mem_fs::FileSystem::default();
         let h = mem_fs::FileSystem::default();
 
-        union.mount("mem_fs_1", "/test_new_filesystem", false, Box::new(a), None);
-        union.mount("mem_fs_2", "/test_create_dir", false, Box::new(b), None);
-        union.mount("mem_fs_3", "/test_remove_dir", false, Box::new(c), None);
-        union.mount("mem_fs_4", "/test_rename", false, Box::new(d), None);
-        union.mount("mem_fs_5", "/test_metadata", false, Box::new(e), None);
-        union.mount("mem_fs_6", "/test_remove_file", false, Box::new(f), None);
-        union.mount("mem_fs_6", "/test_readdir", false, Box::new(g), None);
-        union.mount("mem_fs_6", "/test_canonicalize", false, Box::new(h), None);
+        union
+            .mount(
+                "mem_fs_1".to_string(),
+                PathBuf::from("/test_new_filesystem").as_path(),
+                Box::new(a),
+            )
+            .unwrap();
+        union
+            .mount(
+                "mem_fs_2".to_string(),
+                PathBuf::from("/test_create_dir").as_path(),
+                Box::new(b),
+            )
+            .unwrap();
+        union
+            .mount(
+                "mem_fs_3".to_string(),
+                PathBuf::from("/test_remove_dir").as_path(),
+                Box::new(c),
+            )
+            .unwrap();
+        union
+            .mount(
+                "mem_fs_4".to_string(),
+                PathBuf::from("/test_rename").as_path(),
+                Box::new(d),
+            )
+            .unwrap();
+        union
+            .mount(
+                "mem_fs_5".to_string(),
+                PathBuf::from("/test_metadata").as_path(),
+                Box::new(e),
+            )
+            .unwrap();
+        union
+            .mount(
+                "mem_fs_6".to_string(),
+                PathBuf::from("/test_remove_file").as_path(),
+                Box::new(f),
+            )
+            .unwrap();
+        union
+            .mount(
+                "mem_fs_6".to_string(),
+                PathBuf::from("/test_readdir").as_path(),
+                Box::new(g),
+            )
+            .unwrap();
+        union
+            .mount(
+                "mem_fs_6".to_string(),
+                PathBuf::from("/test_canonicalize").as_path(),
+                Box::new(h),
+            )
+            .unwrap();
 
         union
     }
 
+    fn gen_nested_filesystem() -> UnionFileSystem {
+        let union = UnionFileSystem::new();
+        let a = mem_fs::FileSystem::default();
+        a.open(
+            &PathBuf::from("/data-a.txt"),
+            &OpenOptionsConfig {
+                read: true,
+                write: true,
+                create_new: false,
+                create: true,
+                append: false,
+                truncate: false,
+            },
+        )
+        .unwrap();
+        let b = mem_fs::FileSystem::default();
+        b.open(
+            &PathBuf::from("/data-b.txt"),
+            &OpenOptionsConfig {
+                read: true,
+                write: true,
+                create_new: false,
+                create: true,
+                append: false,
+                truncate: false,
+            },
+        )
+        .unwrap();
+
+        union
+            .mount(
+                "mem_fs_1".to_string(),
+                PathBuf::from("/app/a").as_path(),
+                Box::new(a),
+            )
+            .unwrap();
+        union
+            .mount(
+                "mem_fs_2".to_string(),
+                PathBuf::from("/app/b").as_path(),
+                Box::new(b),
+            )
+            .unwrap();
+
+        union
+    }
+
+    #[tokio::test]
+    async fn test_nested_read_dir() {
+        let fs = gen_nested_filesystem();
+
+        let root_contents: Vec<PathBuf> = fs
+            .read_dir(&PathBuf::from("/"))
+            .unwrap()
+            .map(|e| e.unwrap().path.clone())
+            .collect();
+        assert_eq!(root_contents, vec![PathBuf::from("/app")]);
+
+        let app_contents: HashSet<PathBuf> = fs
+            .read_dir(&PathBuf::from("/app"))
+            .unwrap()
+            .map(|e| e.unwrap().path)
+            .collect();
+        assert_eq!(
+            app_contents,
+            HashSet::from_iter([PathBuf::from("/app/a"), PathBuf::from("/app/b")].into_iter())
+        );
+
+        let a_contents: Vec<PathBuf> = fs
+            .read_dir(&PathBuf::from("/app/a"))
+            .unwrap()
+            .map(|e| e.unwrap().path.clone())
+            .collect();
+        assert_eq!(a_contents, vec![PathBuf::from("/app/a/data-a.txt")]);
+
+        let b_contents: Vec<PathBuf> = fs
+            .read_dir(&PathBuf::from("/app/b"))
+            .unwrap()
+            .map(|e| e.unwrap().path)
+            .collect();
+        assert_eq!(b_contents, vec![PathBuf::from("/app/b/data-b.txt")]);
+    }
+
+    #[tokio::test]
+    async fn test_nested_metadata() {
+        let fs = gen_nested_filesystem();
+
+        assert!(fs.metadata(&PathBuf::from("/")).is_ok());
+        assert!(fs.metadata(&PathBuf::from("/app")).is_ok());
+        assert!(fs.metadata(&PathBuf::from("/app/a")).is_ok());
+        assert!(fs.metadata(&PathBuf::from("/app/b")).is_ok());
+        assert!(fs.metadata(&PathBuf::from("/app/a/data-a.txt")).is_ok());
+        assert!(fs.metadata(&PathBuf::from("/app/b/data-b.txt")).is_ok());
+    }
+
+    #[tokio::test]
+    async fn test_nested_symlink_metadata() {
+        let fs = gen_nested_filesystem();
+
+        assert!(fs.symlink_metadata(&PathBuf::from("/")).is_ok());
+        assert!(fs.symlink_metadata(&PathBuf::from("/app")).is_ok());
+        assert!(fs.symlink_metadata(&PathBuf::from("/app/a")).is_ok());
+        assert!(fs.symlink_metadata(&PathBuf::from("/app/b")).is_ok());
+        assert!(fs
+            .symlink_metadata(&PathBuf::from("/app/a/data-a.txt"))
+            .is_ok());
+        assert!(fs
+            .symlink_metadata(&PathBuf::from("/app/b/data-b.txt"))
+            .is_ok());
+    }
+
     #[tokio::test]
     async fn test_new_filesystem() {
         let fs = gen_filesystem();
@@ -540,19 +520,9 @@ mod tests {
     async fn test_create_dir() {
         let fs = gen_filesystem();
 
-        assert_eq!(
-            fs.create_dir(Path::new("/")),
-            Err(FsError::BaseNotDirectory),
-            "creating a directory that has no parent",
-        );
+        assert_eq!(fs.create_dir(Path::new("/")), Ok(()),);
 
-        let _ = fs_extra::remove_items(&["/test_create_dir"]);
-
-        assert_eq!(
-            fs.create_dir(Path::new("/test_create_dir")),
-            Ok(()),
-            "creating a directory",
-        );
+        assert_eq!(fs.create_dir(Path::new("/test_create_dir")), Ok(()));
 
         assert_eq!(
             fs.create_dir(Path::new("/test_create_dir/foo")),
@@ -597,12 +567,10 @@ mod tests {
     async fn test_remove_dir() {
         let fs = gen_filesystem();
 
-        let _ = fs_extra::remove_items(&["/test_remove_dir"]);
-
         assert_eq!(
             fs.remove_dir(Path::new("/")),
-            Err(FsError::BaseNotDirectory),
-            "removing a directory that has no parent",
+            Err(FsError::PermissionDenied),
+            "cannot remove the root directory",
         );
 
         assert_eq!(
@@ -611,11 +579,7 @@ mod tests {
             "cannot remove a directory that doesn't exist",
         );
 
-        assert_eq!(
-            fs.create_dir(Path::new("/test_remove_dir")),
-            Ok(()),
-            "creating a directory",
-        );
+        assert_eq!(fs.create_dir(Path::new("/test_remove_dir")), Ok(()));
 
         assert_eq!(
             fs.create_dir(Path::new("/test_remove_dir/foo")),
@@ -656,8 +620,6 @@ mod tests {
             !read_dir_names(&fs, "/test_remove_dir").contains(&"foo".to_string()),
             "the foo directory still exists"
         );
-
-        let _ = fs_extra::remove_items(&["/test_remove_dir"]);
     }
 
     fn read_dir_names(fs: &dyn crate::FileSystem, path: &str) -> Vec<String> {
@@ -671,20 +633,18 @@ mod tests {
     async fn test_rename() {
         let fs = gen_filesystem();
 
-        let _ = fs_extra::remove_items(&["./test_rename"]);
-
         assert_eq!(
             fs.rename(Path::new("/"), Path::new("/bar")).await,
-            Err(FsError::BaseNotDirectory),
+            Err(FsError::PermissionDenied),
             "renaming a directory that has no parent",
         );
         assert_eq!(
             fs.rename(Path::new("/foo"), Path::new("/")).await,
-            Err(FsError::BaseNotDirectory),
+            Err(FsError::EntryNotFound),
             "renaming to a directory that has no parent",
         );
 
-        assert_eq!(fs.create_dir(Path::new("/test_rename")), Ok(()));
+        assert_eq!(fs.create_dir(Path::new("/test_rename")), Ok(()),);
         assert_eq!(fs.create_dir(Path::new("/test_rename/foo")), Ok(()));
         assert_eq!(fs.create_dir(Path::new("/test_rename/foo/qux")), Ok(()));
 
@@ -836,15 +796,11 @@ mod tests {
 
         let fs = gen_filesystem();
 
-        let _ = fs_extra::remove_items(&["/test_metadata"]);
-
-        assert_eq!(fs.create_dir(Path::new("/test_metadata")), Ok(()));
-
         let root_metadata = fs.metadata(Path::new("/test_metadata")).unwrap();
 
         assert!(root_metadata.ft.dir);
-        assert!(root_metadata.accessed == root_metadata.created);
-        assert!(root_metadata.modified == root_metadata.created);
+        assert_eq!(root_metadata.accessed, root_metadata.created);
+        assert_eq!(root_metadata.modified, root_metadata.created);
         assert!(root_metadata.modified > 0);
 
         assert_eq!(fs.create_dir(Path::new("/test_metadata/foo")), Ok(()));
@@ -888,10 +844,6 @@ mod tests {
     async fn test_remove_file() {
         let fs = gen_filesystem();
 
-        let _ = fs_extra::remove_items(&["./test_remove_file"]);
-
-        assert!(fs.create_dir(Path::new("/test_remove_file")).is_ok());
-
         assert!(
             fs.new_open_options()
                 .write(true)
@@ -1094,34 +1046,4 @@ mod tests {
         let _ = fs_extra::remove_items(&["./test_canonicalize"]);
     }
     */
-
-    #[tokio::test]
-    #[ignore = "Not yet supported. See https://github.com/wasmerio/wasmer/issues/3678"]
-    async fn mount_to_overlapping_directories() {
-        let top_level = mem_fs::FileSystem::default();
-        ops::touch(&top_level, "/file.txt").unwrap();
-        let nested = mem_fs::FileSystem::default();
-        ops::touch(&nested, "/another-file.txt").unwrap();
-
-        let mut fs = UnionFileSystem::default();
-        fs.mount(
-            "top-level",
-            "/",
-            false,
-            Box::new(top_level),
-            Some("/top-level"),
-        );
-        fs.mount(
-            "nested",
-            "/",
-            false,
-            Box::new(nested),
-            Some("/top-level/nested"),
-        );
-
-        assert!(ops::is_dir(&fs, "/top-level"));
-        assert!(ops::is_file(&fs, "/top-level/file.txt"));
-        assert!(ops::is_dir(&fs, "/top-level/nested"));
-        assert!(ops::is_file(&fs, "/top-level/nested/another-file.txt"));
-    }
 }
