@@ -16,6 +16,9 @@ use std::net::{IpAddr, Ipv4Addr, Ipv6Addr, Shutdown, SocketAddr};
 use std::os::fd::AsRawFd;
 #[cfg(not(target_os = "windows"))]
 use std::os::fd::RawFd;
+#[cfg(windows)]
+use std::os::windows::io::AsRawSocket;
+
 use std::sync::Arc;
 use std::task::Poll;
 use std::time::Duration;
@@ -87,7 +90,6 @@ impl VirtualNetworking for LocalNetworking {
         _reuse_addr: bool,
     ) -> Result<Box<dyn VirtualUdpSocket + Sync>> {
         let socket = mio::net::UdpSocket::bind(addr).map_err(io_err_into_net_error)?;
-        socket2::SockRef::from(&socket).set_nonblocking(true).ok();
 
         #[allow(unused_mut)]
         let mut ret = LocalUdpSocket {
@@ -118,7 +120,7 @@ impl VirtualNetworking for LocalNetworking {
         mut peer: SocketAddr,
     ) -> Result<Box<dyn VirtualTcpSocket + Sync>> {
         let stream = mio::net::TcpStream::connect(peer).map_err(io_err_into_net_error)?;
-        socket2::SockRef::from(&stream).set_nonblocking(true).ok();
+
         if let Ok(p) = stream.peer_addr() {
             peer = p;
         }
@@ -161,9 +163,6 @@ impl LocalTcpListener {
     fn try_accept_internal(&mut self) -> Result<(Box<dyn VirtualTcpSocket + Sync>, SocketAddr)> {
         match self.stream.accept().map_err(io_err_into_net_error) {
             Ok((stream, addr)) => {
-                socket2::SockRef::from(&self.stream)
-                    .set_nonblocking(true)
-                    .ok();
                 let mut socket = LocalTcpStream::new(self.selector.clone(), stream, addr);
                 if let Some(no_delay) = self.no_delay {
                     socket.set_nodelay(no_delay).ok();
@@ -333,6 +332,23 @@ impl LocalTcpStream {
 
         ret
     }
+
+    fn with_sock_ref<F, R>(&self, f: F) -> R
+    where
+        for<'a> F: FnOnce(socket2::SockRef<'a>) -> R,
+    {
+        #[cfg(not(windows))]
+        let r = socket2::SockRef::from(&self.stream);
+
+        #[cfg(windows)]
+        let b = unsafe {
+            std::os::windows::io::BorrowedSocket::borrow_raw(self.stream.as_raw_socket())
+        };
+        #[cfg(windows)]
+        let r = socket2::SockRef::from(&b);
+
+        f(r)
+    }
 }
 
 impl VirtualTcpSocket for LocalTcpStream {
@@ -363,15 +379,14 @@ impl VirtualTcpSocket for LocalTcpStream {
     }
 
     fn set_keepalive(&mut self, keepalive: bool) -> Result<()> {
-        socket2::SockRef::from(&self.stream)
-            .set_keepalive(true)
+        self.with_sock_ref(|s| s.set_keepalive(true))
             .map_err(io_err_into_net_error)?;
         Ok(())
     }
 
     fn keepalive(&self) -> Result<bool> {
-        let ret = socket2::SockRef::from(&self.stream)
-            .keepalive()
+        let ret = self
+            .with_sock_ref(|s| s.keepalive())
             .map_err(io_err_into_net_error)?;
         Ok(ret)
     }
@@ -444,15 +459,13 @@ impl VirtualTcpSocket for LocalTcpStream {
 
 impl VirtualConnectedSocket for LocalTcpStream {
     fn set_linger(&mut self, linger: Option<Duration>) -> Result<()> {
-        socket2::SockRef::from(&self.stream)
-            .set_linger(linger)
+        self.with_sock_ref(|s| s.set_linger(linger))
             .map_err(io_err_into_net_error)?;
         Ok(())
     }
 
     fn linger(&self) -> Result<Option<Duration>> {
-        socket2::SockRef::from(&self.stream)
-            .linger()
+        self.with_sock_ref(|s| s.linger())
             .map_err(io_err_into_net_error)
     }
 
@@ -654,6 +667,25 @@ pub struct LocalUdpSocket {
     backlog: VecDeque<(BytesMut, SocketAddr)>,
 }
 
+impl LocalUdpSocket {
+    fn with_sock_ref<F, R>(&self, f: F) -> R
+    where
+        for<'a> F: FnOnce(socket2::SockRef<'a>) -> R,
+    {
+        #[cfg(not(windows))]
+        let r = socket2::SockRef::from(&self.socket);
+
+        #[cfg(windows)]
+        let b = unsafe {
+            std::os::windows::io::BorrowedSocket::borrow_raw(self.socket.as_raw_socket())
+        };
+        #[cfg(windows)]
+        let r = socket2::SockRef::from(&b);
+
+        f(r)
+    }
+}
+
 impl VirtualUdpSocket for LocalUdpSocket {
     fn set_broadcast(&mut self, broadcast: bool) -> Result<()> {
         self.socket
@@ -702,14 +734,12 @@ impl VirtualUdpSocket for LocalUdpSocket {
     }
 
     fn join_multicast_v4(&mut self, multiaddr: Ipv4Addr, iface: Ipv4Addr) -> Result<()> {
-        socket2::SockRef::from(&self.socket)
-            .join_multicast_v4(&multiaddr, &iface)
+        self.with_sock_ref(|s| s.join_multicast_v4(&multiaddr, &iface))
             .map_err(io_err_into_net_error)
     }
 
     fn leave_multicast_v4(&mut self, multiaddr: Ipv4Addr, iface: Ipv4Addr) -> Result<()> {
-        socket2::SockRef::from(&self.socket)
-            .leave_multicast_v4(&multiaddr, &iface)
+        self.with_sock_ref(|s| s.leave_multicast_v4(&multiaddr, &iface))
             .map_err(io_err_into_net_error)
     }
 
