@@ -56,6 +56,10 @@ pub struct CapabilityThreadingV1 {
     /// time that it will pause the CPU)
     /// (default = off)
     pub enable_exponential_cpu_backoff: Option<Duration>,
+
+    /// Switches to a blocking sleep implementation instead
+    /// of the asynchronous runtime based implementation
+    pub enable_blocking_sleep: bool,
 }
 
 impl CapabilityThreadingV1 {
@@ -64,11 +68,13 @@ impl CapabilityThreadingV1 {
             max_threads,
             enable_asynchronous_threading,
             enable_exponential_cpu_backoff,
+            enable_blocking_sleep,
         } = other;
         self.enable_asynchronous_threading |= enable_asynchronous_threading;
         if let Some(val) = enable_exponential_cpu_backoff {
             self.enable_exponential_cpu_backoff = Some(val);
         }
         self.max_threads = max_threads.or(self.max_threads);
+        self.enable_blocking_sleep |= enable_blocking_sleep;
     }
 }
