@@ -376,6 +376,17 @@ impl FileSystem for WasiFsRoot {
             WasiFsRoot::Backing(fs) => fs.new_open_options(),
         }
     }
+    fn mount(
+        &self,
+        name: String,
+        path: &Path,
+        fs: Box<dyn FileSystem + Send + Sync>,
+    ) -> virtual_fs::Result<()> {
+        match self {
+            WasiFsRoot::Sandbox(f) => f.mount(name, path, fs),
+            WasiFsRoot::Backing(f) => f.mount(name, path, fs),
+        }
+    }
 }
 
 /// Merge the contents of one filesystem into another.
@@ -566,6 +577,17 @@ impl WasiFs {
         }
     }
 
+    /// We need to clear the freed FD list when the journal is replayed as it
+    /// will close lots of file descriptors which will fill the list. We clear
+    /// the list and allocate new FD's instead.
+    ///
+    /// This should only be used when the file descriptors are being managed
+    /// externally (e.g. journals)
+    pub(crate) fn clear_freed_fd_list(&self) {
+        let mut freed_fds = self.freed_fds.write().unwrap();
+        freed_fds.clear();
+    }
+
     /// Closes all the file handles.
     #[allow(clippy::await_holding_lock)]
     pub async fn close_all(&self) {
@@ -2143,6 +2165,14 @@ impl FileSystem for FallbackFileSystem {
     fn new_open_options(&self) -> virtual_fs::OpenOptions {
         Self::fail();
     }
+    fn mount(
+        &self,
+        _name: String,
+        _path: &Path,
+        _fs: Box<dyn FileSystem + Send + Sync>,
+    ) -> virtual_fs::Result<()> {
+        Self::fail()
+    }
 }
 
 pub fn virtual_file_type_to_wasi_file_type(file_type: virtual_fs::FileType) -> Filetype {
@@ -2211,5 +2241,6 @@ pub fn fs_error_into_wasi_err(fs_error: FsError) -> Errno {
         FsError::DirectoryNotEmpty => Errno::Notempty,
         FsError::StorageFull => Errno::Overflow,
         FsError::Lock | FsError::UnknownError => Errno::Io,
+        FsError::Unsupported => Errno::Notsup,
     }
 }
