@@ -1,5 +1,6 @@
 use std::sync::Arc;
 
+use hyper_util::rt::TokioIo;
 use tokio_stream::wrappers::BroadcastStream;
 
 use super::socket_manager::SocketManager;
@@ -18,7 +19,7 @@ impl HyperProxyConnector {
     }
 }
 
-impl Service<Uri> for HyperProxyConnector {
+impl tower::Service<Uri> for HyperProxyConnector {
     type Response = HyperProxyStream;
     type Error = BoxError;
 
@@ -37,7 +38,7 @@ impl Service<Uri> for HyperProxyConnector {
             let (tx, rx) = socket.split();
             Ok(HyperProxyStream {
                 tx,
-                rx,
+                rx: TokioIo::new(rx),
                 terminate: BroadcastStream::new(terminate_rx),
                 terminated: false,
             })
