@@ -27,6 +27,8 @@ use crate::{
     },
 };
 
+use super::to_module_hash;
+
 /// The maximum number of packages that will be loaded in parallel.
 const MAX_PARALLEL_DOWNLOADS: usize = 32;
 
@@ -40,6 +42,7 @@ pub async fn load_package_tree(
 ) -> Result<BinaryPackage, Error> {
     let mut containers = fetch_dependencies(loader, &resolution.package, &resolution.graph).await?;
     containers.insert(resolution.package.root_package.clone(), root.clone());
+    let package_ids = containers.keys().cloned().collect();
     let fs = filesystem(&containers, &resolution.package, root_is_local_dir)?;
 
     let root = &resolution.package.root_package;
@@ -50,6 +53,7 @@ pub async fn load_package_tree(
 
     let loaded = BinaryPackage {
         id: root.clone(),
+        package_ids,
         when_cached: crate::syscalls::platform_clock_time_get(
             wasmer_wasix_types::wasi::Snapshot0Clockid::Monotonic,
             1_000_000,
@@ -160,7 +164,7 @@ fn load_binary_command(
         return legacy_atom_hack(webc, command_name, cmd);
     }
 
-    let hash = webc.manifest().atom_signature(&atom_name)?.into();
+    let hash = to_module_hash(webc.manifest().atom_signature(&atom_name)?);
 
     let atom = atom.with_context(|| {
 
@@ -241,7 +245,7 @@ fn legacy_atom_hack(
         "(hack) The command metadata is malformed. Falling back to the first atom in the WEBC file",
     );
 
-    let hash = webc.manifest().atom_signature(&name)?.into();
+    let hash = to_module_hash(webc.manifest().atom_signature(&name)?);
 
     Ok(Some(BinaryPackageCommand::new(
         command_name.to_string(),
