@@ -3,7 +3,7 @@ use crate::syscalls::*;
 
 /// ### `chdir()`
 /// Sets the current working directory
-#[instrument(level = "debug", skip_all, fields(name = field::Empty), ret)]
+#[instrument(level = "trace", skip_all, fields(name = field::Empty), ret)]
 pub fn chdir<M: MemorySize>(
     mut ctx: FunctionEnvMut<'_, WasiEnv>,
     path: WasmPtr<u8, M>,
