@@ -22,6 +22,7 @@ mod port_route_list;
 mod port_route_remove;
 mod port_unbridge;
 mod proc_exec;
+mod proc_exec2;
 mod proc_fork;
 mod proc_id;
 mod proc_join;
@@ -90,6 +91,7 @@ pub use port_route_list::*;
 pub use port_route_remove::*;
 pub use port_unbridge::*;
 pub use proc_exec::*;
+pub use proc_exec2::*;
 pub use proc_fork::*;
 pub use proc_id::*;
 pub use proc_join::*;
