@@ -119,28 +119,24 @@ pub(super) fn proc_join_internal<M: MemorySize + 'static>(
 
             // We wait for any process to exit (if it takes too long
             // then we go into a deep sleep)
-            let res = __asyncify_with_deep_sleep::<M, _, _>(
-                ctx,
-                Duration::from_millis(50),
-                async move {
-                    let child_exit = process.join_any_child().await;
-                    match child_exit {
-                        Ok(Some((pid, exit_code))) => {
-                            tracing::trace!(%pid, %exit_code, "triggered child join");
-                            trace!(ret_id = pid.raw(), exit_code = exit_code.raw());
-                            JoinStatusResult::ExitNormal(pid, exit_code)
-                        }
-                        Ok(None) => {
-                            tracing::trace!("triggered child join (no child)");
-                            JoinStatusResult::Err(Errno::Child)
-                        }
-                        Err(err) => {
-                            tracing::trace!(%err, "error triggered on child join");
-                            JoinStatusResult::Err(err)
-                        }
+            let res = __asyncify_with_deep_sleep::<M, _, _>(ctx, async move {
+                let child_exit = process.join_any_child().await;
+                match child_exit {
+                    Ok(Some((pid, exit_code))) => {
+                        tracing::trace!(%pid, %exit_code, "triggered child join");
+                        trace!(ret_id = pid.raw(), exit_code = exit_code.raw());
+                        JoinStatusResult::ExitNormal(pid, exit_code)
                     }
-                },
-            )?;
+                    Ok(None) => {
+                        tracing::trace!("triggered child join (no child)");
+                        JoinStatusResult::Err(Errno::Child)
+                    }
+                    Err(err) => {
+                        tracing::trace!(%err, "error triggered on child join");
+                        JoinStatusResult::Err(err)
+                    }
+                }
+            })?;
             return match res {
                 AsyncifyAction::Finish(ctx, result) => ret_result(ctx, result),
                 AsyncifyAction::Unwind => Ok(Errno::Success),
@@ -192,15 +188,11 @@ pub(super) fn proc_join_internal<M: MemorySize + 'static>(
         } else {
             // Wait for the process to finish
             let process2 = process.clone();
-            let res = __asyncify_with_deep_sleep::<M, _, _>(
-                ctx,
-                Duration::from_millis(50),
-                async move {
-                    let exit_code = process.join().await.unwrap_or_else(|_| Errno::Child.into());
-                    tracing::trace!(%exit_code, "triggered child join");
-                    JoinStatusResult::ExitNormal(pid, exit_code)
-                },
-            )?;
+            let res = __asyncify_with_deep_sleep::<M, _, _>(ctx, async move {
+                let exit_code = process.join().await.unwrap_or_else(|_| Errno::Child.into());
+                tracing::trace!(%exit_code, "triggered child join");
+                JoinStatusResult::ExitNormal(pid, exit_code)
+            })?;
             match res {
                 AsyncifyAction::Finish(ctx, result) => ret_result(ctx, result),
                 AsyncifyAction::Unwind => Ok(Errno::Success),
