@@ -10,7 +10,7 @@ use crate::syscalls::*;
 /// ## Parameters
 ///
 /// * `rval` - The exit code returned by the process.
-#[instrument(level = "debug", skip_all, fields(%exitcode), ret)]
+#[instrument(level = "trace", skip_all, fields(%exitcode), ret)]
 pub fn thread_exit(ctx: FunctionEnvMut<'_, WasiEnv>, exitcode: ExitCode) -> Result<(), WasiError> {
     tracing::debug!(tid=%ctx.data().thread.id(), %exitcode);
     Err(WasiError::Exit(exitcode))
